Bots EDI Translator Team
========================

Original Authors
================
* Henk-Jan Ebbers

Awesome Contributors
====================
* Mike Griffin
* Ludovic Watteaux
* Wouter Vanden Hove
* Jannik Waschkau
* Benoit SAGE



See all contributions here: https://gitlab.com/bots-ediint/bots/-/graphs/master
